from arkindex.process.models import FeatureUsage, Worker, WorkerVersion
from arkindex.project.tests import FixtureTestCase


class TestWorkerVersionProperties(FixtureTestCase):

    @classmethod
    def setUpTestData(cls):
        super().setUpTestData()
        cls.worker_reco = Worker.objects.get(slug="reco")
        cls.version_1 = cls.worker_reco.versions.get()

    def test_property_slug_explicit(self):
        version_2 = WorkerVersion.objects.create(
            id="01234567-89ab-cdef-fedc-ba9876543210",
            worker=self.worker_reco,
            configuration={"test": "test1"},
            gpu_usage=FeatureUsage.Disabled,
            version=2
        )
        self.assertEqual(version_2.slug, "reco_012345")

    def test_property_docker_command_empty(self):
        self.assertEqual(self.version_1.docker_command, None)

    def test_property_docker_command_not_empty(self):
        self.version_1.configuration = {"docker": {"command": "mysupercommand"}}
        self.assertEqual(self.version_1.docker_command, "mysupercommand")
        self.version_1.configuration = {"test": "test1"}

    def test_property_docker_shm_size(self):
        self.version_1.configuration = {"docker": {"shm_size": "32b"}}
        self.assertEqual(self.version_1.docker_shm_size, "32b")
